@@ -4,7 +4,7 @@ use warnings;
 package Getopt::Lucid;
 # ABSTRACT: Clear, readable syntax for command line processing
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 our @EXPORT_OK = qw(Switch Counter Param List Keypair);
 our %EXPORT_TAGS = ( all => [ @EXPORT_OK ] );
@@ -798,7 +798,7 @@ Getopt::Lucid - Clear, readable syntax for command line processing
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -834,7 +834,7 @@ version 1.06
      Param("help")->anycase,            # case insensitivity
    );
    $opt = Getopt::Lucid->getopt( \@adv_spec );
-   $opt->validate( 'requires' => ['input'] );
+   $opt->validate({ 'requires' => ['input'] });
  
    # example with a config file
  
@@ -1576,7 +1576,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords David Golden Kevin McGrath Nova Patch Robert Bohne
+=for stopwords David Golden Precious Kevin McGrath Nova Patch Robert Bohne
 
 =over 4
 
@@ -1586,6 +1586,10 @@ David Golden <xdg@xdg.me>
 
 =item *
 
+David Precious <davidp@preshweb.co.uk>
+
+=item *
+
 Kevin McGrath <kmcgrath@cpan.org>
 
 =item *
